diff --git a/gemp-lotr/gemp-lotr-async/src/main/web/includes/changeLog.html b/gemp-lotr/gemp-lotr-async/src/main/web/includes/changeLog.html
index 9b1f05b45..35f061c3a 100644
--- a/gemp-lotr/gemp-lotr-async/src/main/web/includes/changeLog.html
+++ b/gemp-lotr/gemp-lotr-async/src/main/web/includes/changeLog.html
@@ -12,6 +12,7 @@
- "Wizard Staff" now correctly takes a card from deck (not discard) into hand, also shuffles the deck afterwards.
- "Gandalf, Leader of Dwarves" should be able to be played from discard, due to Followers officially having a Race now
(previous change).
+- "Gandalf, Friend of Thorin" now works according to the card image's text.
17 Dec. 2015
- "Armor of Khazad" no longer allows to return itself from discard and can now be transferred.
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/java/com/gempukku/lotro/cards/set30/gandalf/Card30_026.java b/gemp-lotr/gemp-lotr-cards/src/main/java/com/gempukku/lotro/cards/set30/gandalf/Card30_026.java
index af5d89df5..607f3abab 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/java/com/gempukku/lotro/cards/set30/gandalf/Card30_026.java
+++ b/gemp-lotr/gemp-lotr-cards/src/main/java/com/gempukku/lotro/cards/set30/gandalf/Card30_026.java
@@ -10,6 +10,7 @@ import com.gempukku.lotro.filters.Filters;
import com.gempukku.lotro.game.PhysicalCard;
import com.gempukku.lotro.game.state.LotroGame;
import com.gempukku.lotro.logic.actions.ActivateCardAction;
+import com.gempukku.lotro.logic.effects.DrawCardsEffect;
import com.gempukku.lotro.logic.modifiers.CantDiscardFromPlayModifier;
import com.gempukku.lotro.logic.modifiers.Modifier;
import com.gempukku.lotro.logic.modifiers.SpotCondition;
@@ -28,8 +29,8 @@ import java.util.List;
* Strength: 7
* Vitality: 4
* Resitance: 6
* Game Text: The twilight cost of Thorin is -2. Fellowship: Discard 2 Dwarf followers to prevent
* Gandalf from being discarded until the end of turn.
*/
public class Card30_026 extends AbstractCompanion {
public Card30_026() {
@@ -42,19 +43,20 @@ public class Card30_026 extends AbstractCompanion {
List modifiers = new LinkedList();
modifiers.add(
new TwilightCostModifier(self, Filters.name("Thorin"), -2));
+ modifiers.add(
+ new CantDiscardFromPlayModifier(self, "Cannot be discarded", new SpotCondition(2, Race.DWARF, CardType.FOLLOWER), self, Filters.any));
return modifiers;
}
-
+
@Override
protected List getExtraInPlayPhaseActions(String playerId, LotroGame game, PhysicalCard self) {
if (PlayConditions.canUseFPCardDuringPhase(game, Phase.FELLOWSHIP, self)
- && PlayConditions.canDiscardFromPlay(self, game, 2, Race.DWARF, CardType.FOLLOWER)) {
+ && PlayConditions.canDiscardFromPlay(self, game, Race.DWARF, CardType.FOLLOWER)) {
ActivateCardAction action = new ActivateCardAction(self);
- action.appendCost(new ChooseAndDiscardCardsFromPlayEffect(action, playerId, 2, 2, Race.DWARF, CardType.FOLLOWER));
-
- action.appendEffect(new AddUntilEndOfTurnModifierEffect(
- new CantDiscardFromPlayModifier(self, "Cannot be discarded until end of turn", Filters.gandalf, Filters.any)));
+ action.appendCost(new ChooseAndDiscardCardsFromPlayEffect(action, playerId, 1, 1, Race.DWARF, CardType.FOLLOWER));
+ action.appendEffect(
+ new DrawCardsEffect(action, playerId, 3));
return Collections.singletonList(action);
}
@@ -28,8 +29,8 @@ import java.util.List;
* Vitality: 4
* Resitance: 6
- * Game Text: The twilight cost of Thorin is -2. Fellowship: Discard 2 Dwarf followers to prevent
- * Gandalf from being discarded until the end of turn.
+ * Game Text: Wise. The twilight cost of Thorin is -2. While you can spot 2 Dwarf followers, Gandalf cannot be discarded.
+ * Fellowship: Discard a Dwarf follower and add a doubt to draw 3 cards.
*/
public class Card30_026 extends AbstractCompanion {